@@ -1,9 +1,11 @@
 ######################################################################
 package Net::Amazon::Property::Book;
 ######################################################################
+use warnings;
+use strict;
 use base qw(Net::Amazon::Property);
 
-__PACKAGE__->make_accessor($_) for qw(title publisher binding);
+__PACKAGE__->make_accessor($_) for qw(title publisher binding isbn);
 
 ##################################################
 sub new {
@@ -31,6 +33,7 @@ sub init_via_xmlref {
     $self->title($xmlref->{ProductName});
     $self->publisher($xmlref->{Manufacturer});
     $self->binding($xmlref->{Media});
+    $self->isbn($xmlref->{Isbn});
 }
 
 ##################################################
@@ -117,6 +120,10 @@ Returns the book's publishing company as a string.
 
 Returns the book's title as a string.
 
+=item isbn()
+
+Returns the book's ISBN number.
+
 =item new(xmlref => $xmlref)
 
 Initializes an object by passing a hash of hashes structure containing
